[![CircleCI](https://circleci.com/gh/circleci/circleci-docs.svg?style=shield)](https://circleci.com/gh/circleci/circleci-docs)

## CertCV: An easy Certificate copy-paster

This tool is intended for use with openVPN configuration files where you would need to copy a certificate key and a private key to the config file for each client. Automating this process is my goal to save on time, whether it be just one client file or multiple client users.
